@@ -28,9 +28,9 @@
 
 typedef struct _Tracer
 {
-  GMutex *breakpoint_mutex;
-  GCond *breakpoint_cond;
-  GCond *resume_cond;
+  GMutex breakpoint_mutex;
+  GCond breakpoint_cond;
+  GCond resume_cond;
   gboolean breakpoint_hit;
   gboolean resume_requested;
 } Tracer;
